@@ -34,27 +34,29 @@
 #'  quantile method for dates.
 #' @param columns A character string that contains the names of
 #'  columns that should be fixed and their values. These values are
-#'  not determined until [prep.recipe()] is called.
+#'  not determined until [prep()] is called.
 #' @details This step is atypical in that, when baked, the
 #'  `new_data` argument is ignored; the resulting data set is
 #'  based on the fixed and profiled variable's information.
 #'
-#'  When you [`tidy()`] this step, a tibble with columns `terms` (which
-#'  is the columns that will be affected) and `type` (fixed or
-#'  profiled) is returned.
+#'  # Tidying
+#'
+#'  When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
+#'  `terms` (which is the columns that will be affected) and `type` (fixed
+#'  or profiled) is returned.
+#'
+#' @template case-weights-not-supported
 #'
 #' @template step-return
 #' @export
-#' @examples
-#' library(modeldata)
-#' data(okc)
-#'
-#' # Setup a grid across date but keep the other values fixed
-#' recipe(~ diet + height + date, data = okc) %>%
-#'   step_profile(-date, profile = vars(date)) %>%
-#'   prep(training = okc) %>%
-#'   juice
+#' @examplesIf rlang::is_installed(c("modeldata", "ggplot2"))
+#' data(Sacramento, package = "modeldata")
 #'
+#' # Setup a grid across beds but keep the other values fixed
+#' recipe(~ city + price + beds, data = Sacramento) %>%
+#'   step_profile(-beds, profile = vars(beds)) %>%
+#'   prep(training = Sacramento) %>%
+#'   bake(new_data = NULL)
 #'
 #' ##########
 #'
@@ -79,13 +81,17 @@
 #'
 #' grid_data <- bake(disp_grid, new_data = NULL)
 #' grid_data <- grid_data %>%
-#'   mutate(pred = predict(lin_mod, grid_data),
-#'          method = "grid")
+#'   mutate(
+#'     pred = predict(lin_mod, grid_data),
+#'     method = "grid"
+#'   )
 #'
 #' pctl_data <- bake(disp_pctl, new_data = NULL)
 #' pctl_data <- pctl_data %>%
-#'   mutate(pred = predict(lin_mod, pctl_data),
-#'          method = "percentile")
+#'   mutate(
+#'     pred = predict(lin_mod, pctl_data),
+#'     method = "percentile"
+#'   )
 #'
 #' plot_data <- bind_rows(grid_data, pctl_data)
 #'
@@ -93,8 +99,7 @@
 #'
 #' ggplot(plot_data, aes(x = disp, y = pred)) +
 #'   geom_point(alpha = .5, cex = 1) +
-#'   facet_wrap(~ method)
-
+#'   facet_wrap(~method)
 step_profile <- function(recipe,
                          ...,
                          profile = NULL,
@@ -106,31 +111,36 @@ step_profile <- function(recipe,
                          trained = FALSE,
                          skip = FALSE,
                          id = rand_id("profile")) {
-
-  if (pct < 0 | pct > 1)
+  if (pct < 0 | pct > 1) {
     rlang::abort("`pct should be on [0, 1]`")
-  if (length(grid) != 2)
+  }
+  if (length(grid) != 2) {
     rlang::abort("`grid` should have two named elements. See ?step_profile")
-  if (all(sort(names(grid)) == c("len", "ptcl")))
+  }
+  if (all(sort(names(grid)) == c("len", "ptcl"))) {
     rlang::abort("`grid` should have two named elements. See ?step_profile")
-  if (grid$len < 2)
+  }
+  if (grid$len < 2) {
     rlang::abort("`grid$len should be at least 2.`")
-  if (!is.logical(grid$pctl))
+  }
+  if (!is.logical(grid$pctl)) {
     rlang::abort("`grid$pctl should be logical.`")
+  }
 
-  add_step(recipe,
-           step_profile_new(
-             terms = ellipse_check(...),
-             profile = profile,
-             pct = pct,
-             index = index,
-             grid = grid,
-             columns = columns,
-             role = role,
-             trained = trained,
-             skip = skip,
-             id = id
-           )
+  add_step(
+    recipe,
+    step_profile_new(
+      terms = enquos(...),
+      profile = profile,
+      pct = pct,
+      index = index,
+      grid = grid,
+      columns = columns,
+      role = role,
+      trained = trained,
+      skip = skip,
+      id = id
+    )
   )
 }
 
@@ -156,17 +166,17 @@ prep.step_profile <- function(x, training, info = NULL, ...) {
   fixed_names <- recipes_eval_select(x$terms, training, info)
   profile_name <- recipes_eval_select(x$profile, training, info)
 
-  if(length(fixed_names) == 0)
-    rlang::abort("At least one variable should be fixed")
-  if(length(profile_name) != 1)
+  if (length(profile_name) != 1) {
     rlang::abort("Only one variable should be profiled")
-  if(any(profile_name == fixed_names))
+  }
+  if (any(profile_name == fixed_names)) {
     rlang::abort(
       paste0(
         "The profiled variable cannot be in the list of ",
         "variables to be fixed."
-        )
       )
+    )
+  }
   fixed_vals <- lapply(
     training[, fixed_names],
     fixed,
@@ -198,19 +208,19 @@ bake.step_profile <- function(object, new_data, ...) {
   keepers <- c(names(object$columns), names(object$profile))
   # Keep the predictors in the same order
   keepers <- names(new_data)[names(new_data) %in% keepers]
-  new_data <- dplyr::select(new_data,! !keepers)
+  new_data <- dplyr::select(new_data, !!keepers)
 
   for (i in names(object$columns)) {
     new_data[[i]] <- rep(object$columns[[i]], n)
   }
   new_data[[names(object$profile)]] <- object$profile[[1]]
-  as_tibble(new_data)
+  new_data
 }
 
 print.step_profile <-
   function(x, width = max(20, options()$width - 22), ...) {
-    cat("Profiling data set for  ")
-    printer(names(x$profile), x$profile, x$trained, width = width)
+    title <- "Profiling data set for "
+    print_step(names(x$profile), x$profile, x$trained, title, width)
     invisible(x)
   }
 
@@ -221,15 +231,18 @@ tidy.step_profile <- function(x, ...) {
     res <- tibble(terms = x$columns)
     fixed_names <- names(x$columns)
     prof_names <- names(x$profile)
-  }
-  else {
+  } else {
     fixed_names <- sel2char(x$terms)
     prof_names <- sel2char(x$profile)
   }
-  fixed_res <- tibble(terms = fixed_names,
-                      type = rep("fixed", length = length(fixed_names)))
-  prof_res <- tibble(terms = prof_names,
-                     type = rep("profiled", length = length(prof_names)))
+  fixed_res <- tibble(
+    terms = fixed_names,
+    type = rep("fixed", length = length(fixed_names))
+  )
+  prof_res <- tibble(
+    terms = prof_names,
+    type = rep("profiled", length = length(prof_names))
+  )
   res <- bind_rows(fixed_res, prof_res)
   res$id <- x$id
   res
@@ -243,15 +256,16 @@ tidy.step_profile <- function(x, ...) {
 #' @param pct,index,...,grid Options pass from [step_profile()]
 #' @export
 #' @keywords internal
-fixed <- function (x, pct, index, ...) UseMethod("fixed")
+fixed <- function(x, pct, index, ...) UseMethod("fixed")
 
 #' @export
 #' @rdname fixed
 fixed.default <- function(x, pct, index, ...) {
   rlang::abort("No method for determining a value to fix for ",
-       "objects of class(s) ",
-       paste0("'", class(x), "'", collapse = ","),
-       call. = FALSE)
+    "objects of class(s) ",
+    paste0("'", class(x), "'", collapse = ","),
+    call. = FALSE
+  )
 }
 #' @export
 #' @rdname fixed
@@ -279,7 +293,7 @@ fixed.character <- function(x, pct, index, ...) {
 #' @rdname fixed
 fixed.Date <- function(x, pct, index, ...) {
   vals <- c(0, .5, 1)
-  dst <- (vals - pct) ^ 2
+  dst <- (vals - pct)^2
   mthd <- which.min(dst)
   if (mthd == 1) {
     out <- min(x, na.rm = TRUE)
@@ -298,14 +312,14 @@ fixed.POSIXct <- fixed.Date
 
 #' @export
 #' @rdname fixed
-prof <- function (x, grid, ...) UseMethod("prof")
+prof <- function(x, grid, ...) UseMethod("prof")
 
 #' @export
 #' @rdname fixed
 prof.numeric <- function(x, grid, ...) {
-  if(grid$pctl) {
-  pct <- seq(0, 1, length = grid$len)
-  out <- unname(quantile(x, probs = pct, na.rm = TRUE))
+  if (grid$pctl) {
+    pct <- seq(0, 1, length = grid$len)
+    out <- unname(quantile(x, probs = pct, na.rm = TRUE))
   } else {
     out <- seq(
       min(x, na.rm = TRUE),
@@ -341,8 +355,3 @@ prof.POSIXct <- function(x, grid, ...) {
   x <- as.Date(x)
   prof.Date(x, grid, ...)
 }
-
-
-
-
-
